<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Form;

use Laminas\Form\Form;

class LanguageForm extends Form
{
    private $languageCode;

    public function __construct($languageCode, $name = 'language-form', array $options = [])
    {
        parent::__construct($name, $options);
        $this->setAttribute('method', 'post');
        $this->setAttribute('class', 'form-horizontal');

        $this->languageCode = $languageCode;

        $this->addElements();
        $this->addInputFilter();
    }

    protected function addElements()
    {
        $this->add([
            'type'  => 'checkbox',
            'name'  => 'defaultLanguage'.$this->languageCode,
            'attributes' => [
                'value' => 0
            ]
        ]);

        $this->add([
            'type'  => 'text',
            'name'  => 'domain'.$this->languageCode,
            'attributes' => [
                'id'    => 'domain'.$this->languageCode,
                'class' => 'form-control',
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'languageState'.$this->languageCode,
            'attributes' => [
                'value' => 0
            ]
        ]);
    }

    protected function addInputFilter()
    {
        $inputFilter = $this->getInputFilter();

        $inputFilter->add([
            'name'      => 'defaultLanguage'.$this->languageCode,
            'required'  => true,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'domain'.$this->languageCode,
            'required'  => false,
            'filters'   => [
                ['name' => 'StringTrim'],
                ['name' => 'StripTags'],
                ['name' => 'HtmlEntities']
            ],
            'validators'=> [
                [
                    'name'      => 'hostname',
                    'options'   => [
                        'useIdnCheck'   => false,
                        'useTldCheck'   => false
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'languageState'.$this->languageCode,
            'required'  => true,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);
    }
}