<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Service;

use Admin\Data\MultiLanguage;
use Admin\Entity\Region;
use Admin\Entity\RegionContent;
use Doctrine\ORM\EntityManager;

class RegionManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;

    }

    /**
     * 添加地区
     * @param array $data
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     * @throws \Doctrine\Persistence\Mapping\MappingException
     */
    public function addRegion(array $data)
    {
        $classPath = '';
        if($data['regionTopId'] > 0) {
            $regionInfo = $this->entityManager->getRepository(Region::class)->findOneByRegionId($data['regionTopId']);
            if($regionInfo) $classPath = $regionInfo->getRegionPath();
        }

        if (MultiLanguage::REGION_MULTI_LANGUAGE == 1) {
            $region = new Region();
            $region->valuesSet($data);
            $this->entityManager->persist($region);
            $this->entityManager->flush();

            $oneClassPath = empty($classPath) ? $region->getRegionId() : $classPath . ',' . $region->getRegionId();
            $region->setRegionPath($oneClassPath);
            $this->entityManager->flush();

            $regionId = $region->getRegionId();

            foreach (SHOP_LANGUAGE as $language) {
                $regionName = $data['regionName' . $language];
                $regionContent = new RegionContent();
                $regionContent->setLanguageCode($language);
                $regionContent->setRegionId($regionId);
                $regionContent->setRegionName($regionName);

                $this->entityManager->persist($regionContent);
                $this->entityManager->flush();
                $this->entityManager->clear(RegionContent::class);
            }
        } else {
            $regionArray = explode("\r\n", $data['regionName' . MultiLanguage::REGION_DEFAULT_LANGUAGE]);
            foreach ($regionArray as $value) {
                $region = new Region();
                $region->valuesSet($data);
                $this->entityManager->persist($region);
                $this->entityManager->flush();

                $oneClassPath = empty($classPath) ? $region->getRegionId() : $classPath . ',' . $region->getRegionId();
                $region->setRegionPath($oneClassPath);
                $this->entityManager->flush();

                $regionName = $value;
                $regionContent = new RegionContent();
                $regionContent->setLanguageCode(MultiLanguage::REGION_DEFAULT_LANGUAGE);
                $regionContent->setRegionId($region->getRegionId());
                $regionContent->setRegionName($regionName);

                $this->entityManager->persist($regionContent);
                $this->entityManager->flush();

                $this->entityManager->clear(Region::class);
                $this->entityManager->clear(RegionContent::class);
            }
        }
    }

    /**
     * 更新地区
     * @param array $data
     * @param Region $region
     * @return bool
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function editRegion(array $data, Region $region)
    {
        $region->setRegionSort($data['regionSort']);
        $this->entityManager->flush();

        return true;
    }

    /**
     * 批量处理
     * @param array $data
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     * @throws \Doctrine\Persistence\Mapping\MappingException
     */
    public function updateAllRegion(array $data)
    {
        foreach ($data['select_id'] as $key => $value) {
            $region = $this->entityManager->getRepository(Region::class)->findOneByRegionId($value);

            if($data['editAllState'] == 'sort') {
                $region->setRegionSort($data['region_sort'][$value]);
            }
            if($data['editAllState'] == 'del') {
                $subRegionArray = $this->entityManager->getRepository(Region::class)->findBy(['regionTopId' => $region->getRegionId()]);
                if($subRegionArray) {
                    $this->entityManager->clear(Region::class);
                    continue;
                }
                $this->entityManager->remove($region);

                $regionContentList = $this->entityManager->getRepository(RegionContent::class)->findBy(['regionId' => $value]);
                if ($regionContentList) foreach ($regionContentList as $contentValue) {
                    $this->entityManager->remove($contentValue);
                }
            }

            $this->entityManager->flush();
            $this->entityManager->clear(Region::class);
        }
    }

    /**
     * 删除地区
     * @param Region $region
     * @return bool
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function deleteRegion(Region $region)
    {
        $this->entityManager->remove($region);
        $this->entityManager->flush();

        return true;
    }
}