<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Cms\Repository;

use Cms\Entity\Cms;
use Cms\Entity\CmsClass;
use Cms\Entity\CmsClassContent;
use Cms\Entity\CmsContent;
use Cms\Repository\QuerySearch\CmsSearch;
use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;
use Doctrine\ORM\QueryBuilder;

class CmsRepository extends EntityRepository
{
    /**
     * 后台文章列表
     * @param array $search
     * @return \Doctrine\ORM\Query
     */
    public function findListCms(array $search = [])
    {
        $query = $this->getEntityManager()->createQueryBuilder()
            ->select('c')
            ->addSelect("(SELECT n.cmsClassName FROM ".CmsClassContent::class." AS n WHERE n.cmsClassId=c.cmsClassId AND n.languageCode='".SHOP_FONT_LANGUAGE."') AS cmsClassName")
            ->addSelect("(SELECT co.cmsTitle FROM ".CmsContent::class." AS co WHERE co.cmsId=c.cmsId AND co.languageCode='".SHOP_FONT_LANGUAGE."') AS cmsTitle")
            ->from(Cms::class, 'c')
            //->leftJoin(CmsClass::class, 'a', Join::WITH, 'c.cmsClassId=a.cmsClassId')
            ->orderBy('c.cmsSort', 'ASC')
            ->addOrderBy('c.cmsId', 'DESC');

        $query = CmsSearch::querySearchData($search, $query);

        return $query->getQuery();
    }

    /*==============================================下面为前台调用==============================================*/
    /**
     * 前台文章列表
     * @param $languageCode
     * @param $cmsClassId
     * @param array $search
     * @param int $limit
     * @return mixed
     */
    public function shopListCms($languageCode, $cmsClassId, array $search = [], int $limit = 0)
    {
        $query = $this->getEntityManager()->createQueryBuilder()
            ->select('c', 'cc.cmsTitle')
            ->addSelect("(SELECT ac.cmsClassName FROM ".CmsClassContent::class." AS ac WHERE ac.cmsClassId=a.cmsClassId AND ac.languageCode='".$languageCode."') AS cmsClassName")
            ->from(Cms::class, 'c')
            ->leftJoin(CmsClass::class, 'a', Join::WITH, 'c.cmsClassId=a.cmsClassId')
            ->innerJoin(CmsContent::class, 'cc', Join::WITH, 'c.cmsId=cc.cmsId')
            ->where('c.cmsClassId = :cmsClassId')->setParameter('cmsClassId', $cmsClassId)
            ->andWhere('cc.languageCode = :languageCode')->setParameter('languageCode', $languageCode)
            ->andWhere('c.cmsState = :cmsState')->setParameter('cmsState', 1)
            ->orderBy('c.cmsSort', 'ASC')
            ->addOrderBy('c.cmsId', 'DESC');

        if ($limit > 0) {
            $query->setMaxResults($limit);
            return $query->getQuery()->getResult();
        }

        return $query->getQuery();
    }

    /**
     * 前台首页新闻功能
     * @param $languageCode
     * @param int $newsNum
     * @return float|int|mixed|string
     */
    public function findShopIndexNews($languageCode, int $newsNum = 10)
    {
        $query = $this->getEntityManager()->createQueryBuilder()
            ->select('c', 'cm.cmsTitle', 'a.cmsClassName', 'a.cmsClassId')
            ->from(Cms::class, 'c')
            ->innerJoin(CmsClass::class, 'cc', Join::WITH, 'c.cmsClassId=cc.cmsClassId')
            ->innerJoin(CmsClassContent::class, 'a', Join::WITH, 'c.cmsClassId=a.cmsClassId')
            ->leftJoin(CmsContent::class, 'cm', Join::WITH, 'c.cmsId=cm.cmsId')
            ->where('cc.indexNews = :indexNews')->setParameter('indexNews', 1)
            ->andWhere('c.cmsState = :cmsState')->setParameter('cmsState', 1)
            ->andWhere('a.languageCode = :languageCode')->setParameter('languageCode', $languageCode)
            ->andWhere('cm.languageCode = :languageCode')->setParameter('languageCode', $languageCode)
            ->orderBy('c.cmsSort', 'ASC')
            ->addOrderBy('c.cmsId', 'DESC')
            ->setMaxResults($newsNum);

        return $query->getQuery()->getResult();
    }
}