<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Repository;

use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;
use Goods\Entity\GoodsAttributeValue;
use Goods\Entity\GoodsAttributeValueContent;

class GoodsAttributeValueRepository extends EntityRepository
{
    /**
     * 根据属性组获取属性值
     * @param $attributeGroupId
     * @return float|int|mixed|string
     */
    public function findAttributeValueListByGroupId($attributeGroupId)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('v', 'c.valueName')
            ->from(GoodsAttributeValue::class, 'v')
            ->leftJoin(GoodsAttributeValueContent::class, 'c', Join::WITH, 'v.valueId = c.valueId')
            ->where('v.attributeGroupId = :attributeGroupId')->setParameter('attributeGroupId', $attributeGroupId)
            ->andWhere('c.languageCode = :languageCode')->setParameter('languageCode', SHOP_FONT_LANGUAGE)
            ->orderBy('v.valueSort', 'ASC')->addOrderBy('v.valueId', 'ASC');

        return $query->getQuery()->getResult();
    }

    /**
     * 属性值列表
     * @param $attributeId
     * @return float|int|mixed|string
     */
    public function findAttributeValueList($attributeId)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('v', 'c.valueName')
            ->from(GoodsAttributeValue::class, 'v')
            ->leftJoin(GoodsAttributeValueContent::class, 'c', Join::WITH, 'v.valueId = c.valueId')
            ->where('v.attributeId = :attributeId')->setParameter('attributeId', $attributeId)
            ->andWhere('c.languageCode = :languageCode')->setParameter('languageCode', SHOP_FONT_LANGUAGE)
            ->orderBy('v.valueSort', 'ASC');

        return $query->getQuery()->getResult();
    }

    /*===========================================前台===========================================*/
    /**
     * 根据属性组获取属性值
     * @param $attributeGroupId
     * @param $languageCode
     * @return float|int|mixed|string
     */
    public function findShopAttributeValueListByGroupId($attributeGroupId, $languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('v', 'c.valueName')
            ->from(GoodsAttributeValue::class, 'v')
            ->leftJoin(GoodsAttributeValueContent::class, 'c', Join::WITH, 'v.valueId = c.valueId')
            ->where('v.attributeGroupId = :attributeGroupId')->setParameter('attributeGroupId', $attributeGroupId)
            ->andWhere('c.languageCode = :languageCode')->setParameter('languageCode', $languageCode)
            ->orderBy('v.valueSort', 'ASC')->addOrderBy('v.valueId', 'ASC');

        return $query->getQuery()->getResult();
    }
}