<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Repository;

use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;
use Goods\Entity\GoodsInTag;
use Goods\Entity\GoodsTag;
use Goods\Entity\GoodsTagContent;
use Goods\Entity\GoodsTagGroup;
use Goods\Entity\GoodsTagGroupContent;
use Goods\Repository\QuerySearch\GoodsTagSearch;

class GoodsTagRepository extends EntityRepository
{
    /**
     * 商品标签
     * @return float|int|mixed|string
     */
    public function findAllGoodsTag($tagGroupId = 0)
    {
        $query = $this->getEntityManager()->createQueryBuilder()
            ->select('t')
            ->addSelect("(SELECT c.tagName FROM ".GoodsTagContent::class." AS c WHERE c.tagId=t.tagId AND c.languageCode='".SHOP_FONT_LANGUAGE."') AS tagName")
            ->from(GoodsTag::class, 't')
            ->addOrderBy('t.tagSort', 'ASC')
            ->addOrderBy('t.tagId', 'ASC');

        if ($tagGroupId > 0) $query->where('t.tagGroupId = :tagGroupId')->setParameter('tagGroupId', $tagGroupId);

        return $query->getQuery()->getResult();
    }

    /**
     * 获取标签的同时获取商品选中的标签
     * @param $goodsId
     * @return mixed
     */
    public function findGoodsTagAndInGoods($goodsId)
    {
        $query = $this->getEntityManager()->createQueryBuilder()
            ->select('t')
            ->addSelect("(SELECT i.inTagId FROM ".GoodsInTag::class." as i WHERE i.tagId=t.tagId AND i.goodsId = $goodsId) as inTagId")
            ->addSelect("(SELECT c.tagName FROM ".GoodsTagContent::class." AS c WHERE c.tagId=t.tagId AND c.languageCode='".SHOP_FONT_LANGUAGE."') AS tagName")
            ->from(GoodsTag::class, 't')
            ->orderBy('t.tagSort', 'ASC')->addOrderBy('t.tagId', 'ASC');

        return $query->getQuery()->getResult();
    }

    /**
     * 商品标签列表
     * @param array $search
     * @return mixed
     */
    public function findAllGoodsTagList(array $search = [])
    {
        $query = $this->getEntityManager()->createQueryBuilder()
            ->select('t', 'g')
            ->addSelect("(SELECT cg.tagGroupName FROM ".GoodsTagGroupContent::class." AS cg WHERE cg.tagGroupId=t.tagGroupId AND cg.languageCode='".SHOP_FONT_LANGUAGE."') AS tagGroupName")
            ->addSelect("(SELECT c.tagName FROM ".GoodsTagContent::class." AS c WHERE c.tagId=t.tagId AND c.languageCode='".SHOP_FONT_LANGUAGE."') AS tagName")
            ->addSelect('(SELECT COUNT(i.inTagId) FROM '.GoodsInTag::class.' AS i WHERE i.tagId=t.tagId) AS goodsNum')
            ->from(GoodsTag::class, 't')
            ->leftJoin('t.oneTagGroup', 'g')
            ->orderBy('t.tagGroupId', 'ASC')
            ->addOrderBy('t.tagSort', 'ASC')
            ->addOrderBy('t.tagId', 'ASC');

        if (isset($search['tag_name']) && !empty($search['tag_name'])) $query->having($query->expr()->like('tagName', ':tagName'))->setParameter('tagName', '%'.$search['tag_name'].'%');

        $query = GoodsTagSearch::querySearch($search, $query);

        return $query->getQuery()->getResult();
    }

    /*==============================================下面为前台调用==============================================*/

    /**
     * 购物车中获取规格商品的规格信息
     * @param $tagIdArray
     * @param $languageCode
     * @return float|int|mixed|string
     */
    public function findGoodsTagAndTagGroup($tagIdArray, $languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('t')
            ->addSelect("(SELECT c.tagGroupName FROM ".GoodsTagGroupContent::class." AS c WHERE c.tagGroupId=t.tagGroupId AND c.languageCode='".$languageCode."') AS tagGroupName")
            ->addSelect("(SELECT tc.tagName FROM ".GoodsTagContent::class." AS tc WHERE tc.tagId=t.tagId AND tc.languageCode='".$languageCode."') AS tagName")
            ->from(GoodsTag::class, 't')
            ->innerJoin(GoodsTagGroup::class, 'g', Join::WITH, 't.tagGroupId=g.tagGroupId')
            ->where($query->expr()->in('t.tagId', $tagIdArray))
            ->orderBy('g.tagGroupSort', 'ASC');

        return $query->getQuery()->getResult();
    }

    /**
     * 获取标签组ID数组对应的标签
     * @param array $idArray
     * @param $languageCode
     * @return float|int|mixed|string
     */
    public function findGoodsTagInTagGroupId(array $idArray, $languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('t')
            ->addSelect("(SELECT tc.tagName FROM ".GoodsTagContent::class." AS tc WHERE tc.tagId=t.tagId AND tc.languageCode='".$languageCode."') AS tagName")
            ->from(GoodsTag::class, 't')
            ->where($query->expr()->in('t.tagGroupId', $idArray))
            ->orderBy('t.tagSort', 'ASC');

        return $query->getQuery()->getResult();
    }
}