<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace User\Service;

use Doctrine\ORM\EntityManager;
use User\Entity\UserGroupContent;

class UserGroupContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加或编辑客户组内容
     * @param array $data
     * @param $userGroupId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditUserGroupContent(array $data, $userGroupId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $userGroupContent = $this->entityManager->getRepository(UserGroupContent::class)->findOneBy(['userGroupId' => $userGroupId, 'languageCode' => $language]);
            if ($userGroupContent) {
                $userGroupContent->setUserGroupName($data['userGroupName'.$language]);
            } else {
                $userGroupContent = new UserGroupContent();
                $userGroupContent->setUserGroupId($userGroupId);
                $userGroupContent->setLanguageCode($language);
                $userGroupContent->setUserGroupName($data['userGroupName'.$language]);

                $this->entityManager->persist($userGroupContent);
            }
            $this->entityManager->flush();
        }
    }

    /**
     * 删除客户组内容
     * @param $userGroupId
     * @return void
     */
    public function deleteUserGroupContent($userGroupId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(UserGroupContent::class, 'c')->where($qb->expr()->eq('c.userGroupId', $userGroupId));
        $qb->getQuery()->execute();
    }
}