<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace User\Validator;

use Laminas\I18n\Translator\Translator;
use Laminas\Validator\AbstractValidator;

class UserIntegralType2Validator extends AbstractValidator
{
    const NOT_SCALAR    = 'notScalar';
    const INVALID_VALUE = 'invalidValue';

    protected $options = [
        'userInfo'
    ];

    protected $messageTemplates = [];

    public function __construct($options = null)
    {
        if(is_array($options)) {
            if(isset($options['userInfo']))         $this->options['userInfo']      = $options['userInfo'];
        }

        $trans = new Translator();
        $this->messageTemplates = [
            self::NOT_SCALAR    => $trans->translate("这不是一个标准输入值"),
            self::INVALID_VALUE => $trans->translate("超出有效范围的数值")
        ];

        parent::__construct($options);
    }

    public function isValid($value, $context = null)
    {
        if(!is_scalar($value)) {
            $this->error(self::NOT_SCALAR);
            return false;
        }

        if($value <= 0) return true;

        if($this->options['userInfo'] == null) {
            $isValid = false;
        } else {
            $changeIntegralNum = $context['changeIntegral2'].$value;
            $integralNum = $this->options['userInfo']->getIntegralType2Num() + $changeIntegralNum;
            if($integralNum < 0)
                $isValid = false;
            else
                $isValid = true;
        }

        if(!$isValid) $this->error(self::INVALID_VALUE);

        return $isValid;
    }
}